pecos.decoders
==============

.. automodule:: pecos.decoders



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.decoders.dummy_decoder
   pecos.decoders.mwpm2d
